<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Check if class already exists

//if (!class_exists("NNRobots_Content_Fire_DB")):

/**
 * This class will perform all databse related tasks to manage all content fires
 *
 * @since 1.0.0
 *
 */
include_once(NNROBOTS_CONTENT_FIRE_PLUGIN_DIR . "/admin/model/list-table.php");

/**
 * NNRobots_Content_Fire_DB class.
 */
class NNRobots_Content_Fire_DB {

	/**
	 * table_name
	 *
	 * (default value: 'nnrobots_content_fire')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	private static $table_name = 'nnrobots_content_fire';

	/**
	 * Contructor of this class.
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	Instance
	 */
	function __construct() {

		self::createTable();

	}

	/**
	 * Creates the table used to store all content fire data
	 *
	 * @access public
	 * @return void
	 */
	static function createTable() {
		global $wpdb;

		$wpdb->query("
			CREATE TABLE IF NOT EXISTS `" . self::getTableName() . "` (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`name` varchar(60) NOT NULL DEFAULT '',
				`title` mediumtext NOT NULL,
				`text` mediumtext NOT NULL,
				`image` int(11) NOT NULL,
				`news_letter` longtext NOT NULL DEFAULT '',
				`template` longtext NOT NULL,
				`trigger` longtext NOT NULL,
				`style` longtext NOT NULL,
				`active` varchar(8) NOT NULL DEFAULT 'Active',
				`args` longtext,
				PRIMARY KEY (`id`)
			) ENGINE=InnoDB DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci AUTO_INCREMENT=1;
		");
	}

	/**
	 * Add data
	 *
	 * @since 1.0.0
	 *
	 * @param	data to be added
	 * @return	false if error, otherwise nothing
	 */
	public function add_data($val) {

		global $wpdb;

		if(!is_array($val) || $val['name'] == "")
			return false;

		$result = $wpdb->query($wpdb->prepare("INSERT INTO `" . self::getTableName() . "` (
				`name`,
				`title`,
				`text`,
				`image`,
				`news_letter`,
				`template`,
				`trigger`,
				`style`,
				`active`,
				`args`
			) VALUES (%s, %s, %s, %d, %s, %s, %s, %s, %s, %s)",
				$val['name'],
				$val['title'],
				$val['text'],
				$val['image'],
				serialize($val['news_letter']),
				serialize($val['template']),
				serialize($val['trigger']),
				serialize($val['style']),
				$val['active'],
				serialize($val['args'])
			)
		);

		return $wpdb->insert_id;
	}

	/**
	 * Update data
	 *
	 * @since 1.0.0
	 *
	 * @param	data to be updated
	 * @return	false if error, otherwise nothing
	 */
	public function update_data($val) {

		global $wpdb;

		if(!is_array($val) || $val['id'] == "")
			return false;

		$result = $wpdb->query($wpdb->prepare(
			"UPDATE `" . self::getTableName() . "` SET
				`name` = %s,
				`title` = %s,
				`text` = %s,
				`image` = %d,
				`news_letter` = %s,
				`template` = %s,
				`trigger` = %s,
				`style` = %s,
				`active` = %s,
				`args` = %s
			WHERE id = %d",
				$val['name'],
				$val['title'],
				$val['text'],
				$val['image'],
				serialize($val['news_letter']),
				serialize($val['template']),
				serialize($val['trigger']),
				serialize($val['style']),
				$val['active'],
				serialize($val['args']),
				$val['id']
			)
		);

		return $result;
	}

	/**
	 * Get all content fires
	 *
	 * @since 1.0.0
	 *
	 * @param	id
	 * @return	data of content_fire
	 */
	public function get_content_fires() {

		global $wpdb;

		$data = $wpdb->get_results("SELECT * FROM `" . self::getTableName() . "`", 'ARRAY_A');

		$vals = array();

		foreach($data as $row) {
			$val = array();

			$val["id"]           = $row["id"];
			$val["name"]         = $row["name"];
			$val["title"]        = $row["title"];
			$val["text"]         = $row["text"];
			$val["image"]        = $row["image"];
			$val["news_letter"]  = $row["news_letter"];
			$val["template"]     = $row["template"];
			$val["trigger"]      = $row["trigger"];
			$val["style"]        = $row["style"];
			$val["active"]       = $row["active"];
			$val["args"]         = $row["args"];

			$vals[] = $val;
		}

		return $vals;
	}

	/**
	 * Get all Active content fires
	 *
	 * @since 1.0.0
	 *
	 * @param	id
	 * @return	data of content_fire
	 */
	public function get_active() {

		global $wpdb;

		$data = $wpdb->get_results("SELECT * FROM `" . self::getTableName() . "` WHERE `active` = 'Active'", 'ARRAY_A');

		$vals = array();

		foreach($data as $row) {
			$val = array();

			$val["id"]           = $row["id"];
			$val["name"]         = $row["name"];
			$val["title"]        = $row["title"];
			$val["text"]         = $row["text"];
			$val["image"]        = $row["image"];
			$val["news_letter"]  = $row["news_letter"];
			$val["template"]     = $row["template"];
			$val["trigger"]      = $row["trigger"];
			$val["style"]        = $row["style"];
			$val["active"]       = $row["active"];
			$val["args"]         = $row["args"];

			$vals[] = $val;
		}

		return $vals;
	}

	/**
	 * Get all Inactive content fires
	 *
	 * @since 1.0.0
	 *
	 * @param	id
	 * @return	data of content_fire
	 */
	public function get_inactive() {

		global $wpdb;

		$data = $wpdb->get_results("SELECT * FROM `" . self::getTableName() . "` WHERE `active` = 'Inactive'", 'ARRAY_A');

		$vals = array();

		foreach($data as $row) {
			$val = array();

			$val["id"]           = $row["id"];
			$val["name"]         = $row["name"];
			$val["title"]        = $row["title"];
			$val["text"]         = $row["text"];
			$val["image"]        = $row["image"];
			$val["news_letter"]  = $row["news_letter"];
			$val["template"]     = $row["template"];
			$val["trigger"]      = $row["trigger"];
			$val["style"]        = $row["style"];
			$val["active"]       = $row["active"];
			$val["args"]         = $row["args"];

			$vals[] = $val;
		}

		return $vals;
	}

	/**
	 * Get the data from id
	 *
	 * @since 1.0.0
	 *
	 * @param	id
	 * @return	data of content_fire
	 */
	public function get_data_from_id($id) {

		global $wpdb;

		$data = $wpdb->get_results($wpdb->prepare("SELECT * FROM `" . self::getTableName() . "` WHERE `id` = %d", (int) $id), 'ARRAY_A');

		foreach($data as $row) {
			$val = array();

			$val["id"]           = $row["id"];
			$val["name"]         = $row["name"];
			$val["title"]        = $row["title"];
			$val["text"]         = $row["text"];
			$val["image"]        = $row["image"];
			$val["news_letter"]  = $row["news_letter"];
			$val["template"]     = $row["template"];
			$val["trigger"]      = $row["trigger"];
			$val["style"]        = $row["style"];
			$val["active"]       = $row["active"];
			$val["args"]         = $row["args"];
		}

		if (isset($val)) {
			return $val;
		}

		return null;
	}

	/**
	 * Set to active or inactive
	 *
	 * @since 1.0.0
	 *
	 * @param	record id
	 * @param	value to set
	 * @return	false if error, otherwise nothing
	 */
	public function set_active($id, $active) {

		global $wpdb;

		$result = $wpdb->query($wpdb->prepare("UPDATE `" . self::getTableName() . "` SET active = %s WHERE id = %d", $active, $id));
	}

	/**
	 * Delete data from id
	 *
	 * @since 1.0.0
	 *
	 * @param	id
	 * @return	N/A
	 */
	public function delete_data($id) {

		global $wpdb;

		$result = $wpdb->query($wpdb->prepare("DELETE FROM `" . self::getTableName() . "` WHERE id = %d", $id));
	}

	/**
	 * Returns the table name with multisite support
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	public static function getTableName() {

		global $wpdb;

		return $wpdb->prefix . self::$table_name;
	}

	/**
	 * Mulit-byte Unserialize
	 *
	 * UTF-8 will screw up a serialized string
	 *
	 * @access private
	 * @param string
	 * @return string
	 */
	public static function mb_unserialize($string) {

		if ( !is_string($string) ) {
			return $string;
		}

	    $string2 = preg_replace_callback(
	        '!s:(\d+):"(.*?)";!s',
	        function($m){
	            $len = strlen($m[2]);
	            $result = "s:$len:\"{$m[2]}\";";
	            return $result;

	        },
	        $string);
	    return unserialize($string2);
	}
}

//endif;
?>